audit_findings

Function audit_findings 

pub fn audit_findings(db: &Database, source: &Source) -> Vec<Finding>
Audit an opened Database and convert each anomaly to the canonical Finding under the supplied Source, ready to merge into a Report.